import { NextRequest, NextResponse } from 'next/server';
import fs from 'fs';
import path from 'path';

// Function to get the total number of exams available
function getTotalExams(): number {
  try {
    const examDir = path.join(process.cwd(), 'data', 'examen');
    const files = fs.readdirSync(examDir).filter(file => file.endsWith('.ts'));
    return files.length;
  } catch (error) {
    console.error('Error getting total exams:', error);
    return 3; // Default fallback to 3 exams if there's an error
  }
}

export async function GET(request: NextRequest) {
  // Get the cookie directly from the request
  const examTrackerCookie = request.cookies.get('exam-tracker');
  
  let currentExam = 1;
  const totalExams = getTotalExams();
  
  if (examTrackerCookie) {
    // If the cookie exists, parse it and increment
    try {
      currentExam = parseInt(examTrackerCookie.value);
      // If the user has seen all exams, start over
      if (currentExam >= totalExams) {
        currentExam = 1;
      } else {
        currentExam += 1;
      }
    } catch (e) {
      currentExam = 1;
    }
  }
  
  // Create the response with the exam data
  const response = NextResponse.json({ 
    examNumber: currentExam,
    totalExams: totalExams
  });
  
  // Set the cookie to expire in 1 year
  response.cookies.set({
    name: 'exam-tracker',
    value: currentExam.toString(),
    expires: Date.now() + 365 * 24 * 60 * 60 * 1000,
    path: '/'
  });
  
  return response;
}
